from typing import Protocol, Iterable, Sized

from matchescu.typing import EntityReferenceIdentifier


class BinaryComparisonSpace(
    Iterable[tuple[EntityReferenceIdentifier, EntityReferenceIdentifier]],
    Sized,
    Protocol,
):
    def put(
        self, left: EntityReferenceIdentifier, right: EntityReferenceIdentifier
    ) -> None:
        pass



from matchescu.reference_store.comparison_space._in_memory import (
    InMemoryComparisonSpace,
)
from matchescu.reference_store.comparison_space._protocol import BinaryComparisonSpace


__all__ = ["BinaryComparisonSpace", "InMemoryComparisonSpace"]
